@@ -4,6 +4,7 @@ use crate::event::Event;
 use crate::key::*;
 use crate::platform::Platform;
 use crate::types::{Key, KeyValue};
+use crate::utils::as_i32;
 use crate::Pyxel;
 
 enum KeyState {
@@ -59,21 +60,19 @@ impl Input {
             Event::Minimized => {}
 
             // Key events
-            Event::KeyDown { key } => {
-                if (KEY_MIN_VALUE..=KEY_MAX_VALUE).contains(&key) {
-                    self.press_key(key, frame_count);
-                    self.input_keys.push(key);
-                    if let Some(key) = Self::get_common_key(key) {
-                        self.press_key(key, frame_count);
-                    }
+            Event::KeyDown { keycode } => {
+                self.press_key(keycode, frame_count);
+                if let Some(keycode) = to_integrated_key(keycode) {
+                    self.press_key(keycode, frame_count);
+                }
+                if is_keyboard_key(keycode) {
+                    self.input_keys.push(keycode);
                 }
             }
-            Event::KeyUp { key } => {
-                if (KEY_MIN_VALUE..=KEY_MAX_VALUE).contains(&key) {
-                    self.release_key(key, frame_count);
-                    if let Some(key) = Self::get_common_key(key) {
-                        self.release_key(key, frame_count);
-                    }
+            Event::KeyUp { keycode } => {
+                self.release_key(keycode, frame_count);
+                if let Some(keycode) = to_integrated_key(keycode) {
+                    self.release_key(keycode, frame_count);
                 }
             }
             Event::TextInput { text } => {
@@ -131,16 +130,6 @@ impl Input {
         }
     }
 
-    fn get_common_key(key: Key) -> Option<Key> {
-        match key {
-            KEY_LSHIFT | KEY_RSHIFT => Some(KEY_SHIFT),
-            KEY_LCTRL | KEY_RCTRL => Some(KEY_CTRL),
-            KEY_LALT | KEY_RALT => Some(KEY_ALT),
-            KEY_LGUI | KEY_RGUI => Some(KEY_GUI),
-            _ => None,
-        }
-    }
-
     fn press_key(&mut self, key: Key, frame_count: u32) {
         self.key_states
             .insert(key, KeyState::Pressed { frame_count });
@@ -225,28 +214,31 @@ impl Pyxel {
         self.input.is_mouse_visible = is_visible;
     }
 
-    pub fn set_btnp(&mut self, key: Key) {
-        self.input.press_key(key, self.frame_count());
-        if (KEY_MIN_VALUE..=KEY_MAX_VALUE).contains(&key) {
-            self.input.input_keys.push(key);
-            if let Some(key) = Input::get_common_key(key) {
+    pub fn setbtn(&mut self, key: Key, key_state: bool) {
+        if key_state {
+            self.input.press_key(key, self.frame_count());
+            if let Some(key) = to_integrated_key(key) {
                 self.input.press_key(key, self.frame_count());
             }
+            if is_keyboard_key(key) {
+                self.input.input_keys.push(key);
+            }
+        } else {
+            self.input.release_key(key, self.frame_count());
+            if let Some(key) = to_integrated_key(key) {
+                self.input.release_key(key, self.frame_count());
+            }
         }
     }
 
-    pub fn set_btnr(&mut self, key: Key) {
-        self.input.release_key(key, self.frame_count());
-        if let Some(key) = Input::get_common_key(key) {
-            self.input.release_key(key, self.frame_count());
-        }
-    }
-
-    pub fn set_btnv(&mut self, key: Key, key_value: KeyValue) {
+    pub fn setbtnv(&mut self, key: Key, key_value: f64) {
+        let key_value = as_i32(key_value);
         self.input.key_values.insert(key, key_value);
     }
 
-    pub fn move_mouse(&mut self, x: i32, y: i32) {
+    pub fn setmpos(&mut self, x: f64, y: f64) {
+        let x = as_i32(x);
+        let y = as_i32(y);
         self.input.key_values.insert(MOUSE_POS_X, x);
         self.input.key_values.insert(MOUSE_POS_Y, y);
         self.platform.move_cursor(x, y);
